@@ -1,7 +1,6 @@
 #include "CovarianceFunction.h"
 
 using namespace std;
-using namespace itpp;
 
 CovarianceFunction::CovarianceFunction(string name)
 {
@@ -21,7 +20,7 @@ CovarianceFunction::~CovarianceFunction()
 void CovarianceFunction::computeSymmetric(double &c, const vec& x) const 
 {
    mat C(1,1);
-   computeSymmetric(C,x.transpose());
+   computeSymmetric(C,x.t());
    c = C(0,0);
 }
 
@@ -29,32 +28,33 @@ void CovarianceFunction::computeSymmetric(double &c, const vec& x) const
 void CovarianceFunction::computeSymmetric(mat& C, const mat& X) const
 {
 	// ensure that data dimensions match supplied covariance matrix
-	assert(C.rows() == X.rows());
-	assert(C.cols() == X.rows());
+	
+	
 
-	if (X.rows() == 1)
+	if (X.n_rows == 1)
 	{
-	    C.set(0, 0, computeDiagonalElement(X.get_row(0)));
-	    return;
+	    // C.set(0, 0, computeDiagonalElement(X.row(0)));
+        C(0,0) = computeDiagonalElement(X.row(0).t());
+        return;
 	}
 	
 	// calculate the lower and upper triangles
 	double d;
 	
-	for(int i=0; i<X.rows() ; i++)
+	for(unsigned int i=0; i<X.n_rows ; i++)
 	{
-		for(int j=0; j<i; j++)
+		for(unsigned int j=0; j<i; j++)
 		{
-		    d = computeElement(X.get_row(i), X.get_row(j));
-		    C.set(i, j, d);
-			C.set(j, i, d);
+		    d = computeElement(X.row(i).t(), X.row(j).t());
+		    C(i, j) = d;
+			C(j, i) = d;
 		}
 	}
 
 	// calculate the diagonal part
-	for(int i=0; i<X.rows() ; i++)
+	for(unsigned int i=0; i<X.n_rows ; i++)
 	{
-		C.set(i, i, computeDiagonalElement(X.get_row(i)));
+		C(i, i) = computeDiagonalElement(X.row(i).t());
 	}
 }
 
@@ -71,9 +71,9 @@ void CovarianceFunction::computeSymmetricGrad(vec& V, const mat& X) const
 void CovarianceFunction::computeCovariance(vec& c, const mat& X, const vec& x) const
 {
     mat Xmat(x);
-    mat C(X.rows(),1);
-    computeCovariance(C,X,Xmat.transpose());
-    c = C.get_col(0);
+    mat C(X.n_rows,1);
+    computeCovariance(C,X,Xmat.t());
+    c = C.col(0);
 }
 
 /**
@@ -81,14 +81,14 @@ void CovarianceFunction::computeCovariance(vec& c, const mat& X, const vec& x) c
  */
 void CovarianceFunction::computeCovariance(mat& C, const mat& X1, const mat& X2) const
 {
-	assert(C.rows() == X1.rows());
-	assert(C.cols() == X2.rows());
+	
+	
 
-	for(int i=0; i<X1.rows() ; i++)
+	for(unsigned int i=0; i<X1.n_rows ; i++)
 	{
-		for(int j=0; j<X2.rows(); j++)
+		for(unsigned int j=0; j<X2.n_rows; j++)
 		{
-			C.set(i, j, computeElement(X1.get_row(i), X2.get_row(j)));
+			C(i, j) = computeElement(X1.row(i).t(), X2.row(j).t());
 		}
 	}
 }
@@ -96,18 +96,18 @@ void CovarianceFunction::computeCovariance(mat& C, const mat& X1, const mat& X2)
 void CovarianceFunction::computeDiagonal(mat& C, const mat& X) const
 {
 	// calculate the diagonal part
-	for(int i=0; i<X.rows() ; i++)
+	for(unsigned int i=0; i<X.n_rows ; i++)
 	{
-		C.set(i, i, computeDiagonalElement(X.get_row(i)));
+		C(i, i) = computeDiagonalElement(X.row(i));
 	}
 }
 
 void CovarianceFunction::computeDiagonal(vec& C, const mat& X) const
 {
 	// calculate the diagonal part
-	for(int i=0; i<X.rows() ; i++)
+	for(unsigned int i=0; i<X.n_rows ; i++)
 	{
-		C.set(i, computeDiagonalElement(X.get_row(i)));
+		C(i) = computeDiagonalElement(X.row(i).t());
 	}
 }
 
@@ -118,37 +118,35 @@ void CovarianceFunction::computeDiagonal(vec& C, const mat& X) const
  */
 void CovarianceFunction::displayCovarianceParameters(int nspaces) const
 {
-	cout.setf(ios::fixed);
-	cout.precision(4);
-
 	string space = string(nspaces, ' ');
 	
-	cout << space << "Covariance function : " << covarianceName << endl;
+	Rprintf("%s Covariance function : %s\n", space.c_str(), covarianceName.c_str());
 
 	vec t = getParameters();
 
-	for(int i=0; i < (t.size()); i++)
+	for(unsigned int i=0; i < (t.size()); i++)
 	{
-		cout << space << getParameterName(i) << " (P" << (i) << ") : ";
-		cout << (transforms[i]->backwardTransform(t(i)));
+		Rprintf("%s %s  (P%d) :", space.c_str(), getParameterName(i).c_str(), i);
+		Rprintf("%f", transforms[i]->backwardTransform(t(i)));
+		/*
 		if(transformsApplied)
 		{
-			cout  << " (" << transforms[i]->type() << " transformed)";
+			Rprintf(" (%s)", transforms[i]->type().c_str());
 		}
 		else
 		{
-			cout << " (no transform applied)";
+            Rprintf( " (no transform applied)" );
 		}
-		cout << endl;
+		*/
+		Rprintf("\n");
 	}
-	// cout << "====================" << endl;
 
 }
 
 void CovarianceFunction::setParameters(const vec p)
 {
-	assert(transforms.size() == p.size());
-	for(int i = 0; i < getNumberParameters() ; i++)
+	
+	for(unsigned int i = 0; i < getNumberParameters() ; i++)
 	{
 		setParameter(i, transforms[i]->backwardTransform(p(i)));
 	}
@@ -156,26 +154,26 @@ void CovarianceFunction::setParameters(const vec p)
 
 vec CovarianceFunction::getParameters() const
 {
-	assert(transforms.size() == numberParameters);
+	
 	vec result;
 	result.set_size(getNumberParameters());
-	for(int i = 0; i < getNumberParameters() ; i++)
+	for(unsigned int i = 0; i < getNumberParameters() ; i++)
 	{
 		result[i] = transforms[i]->forwardTransform(getParameter(i));
 	}
 	return result;
 }
 
-int CovarianceFunction::getNumberParameters() const
+unsigned int CovarianceFunction::getNumberParameters() const
 {
 	return numberParameters;
 }
 
-void CovarianceFunction::setTransform(int parameterNumber, Transform* newTransform)
+void CovarianceFunction::setTransform(unsigned int parameterNumber, Transform* newTransform)
 {
-	assert(parameterNumber >= 0);
-	assert(parameterNumber < getNumberParameters());
-	assert(parameterNumber < transforms.size());
+	
+	
+	
 	transforms[parameterNumber] = newTransform;
 }
 
@@ -192,27 +190,27 @@ void CovarianceFunction::setDefaultTransforms()
 	transformsApplied = true;
 }
 
-Transform* CovarianceFunction::getTransform(int parameterNumber) const
+Transform* CovarianceFunction::getTransform(unsigned int parameterNumber) const
 {
-	assert(parameterNumber >= 0);
-	assert(parameterNumber < getNumberParameters());
+	
+	
 	return transforms[parameterNumber];
 }
 
 void CovarianceFunction::computeDistanceMatrix(mat& DM, const mat& X) const
 {
 	double value;
-	assert(DM.rows() == X.rows());
-	assert(DM.cols() == X.rows());
+	
+	
 
-	for(int i=0; i<X.rows() ; i++)
+	for(unsigned int i=0; i<X.n_rows ; i++)
 	{
-		for(int j=0; j<i; j++)
+		for(unsigned int j=0; j<i; j++)
 		{
-			value = sum( sqr( X.get_row(i) - X.get_row(j) ) );
-			DM.set(i, j, value);
-			DM.set(j, i, value);
+			value = arma::accu( arma::square( X.row(i) - X.row(j) ) );
+			DM(i, j) = value;
+			DM(j, i) = value;
 		}
-		DM.set(i, i, 0.0);
+		DM(i, i) = 0.0;
 	}
 }
